Module: ForemanOpenscap
- Defined in:
- app/models/concerns/foreman_openscap/policy_extensions.rb,
lib/foreman_openscap.rb,
lib/foreman_openscap/engine.rb,
lib/foreman_openscap/version.rb,
app/models/concerns/foreman_openscap/host_extensions.rb,
app/models/concerns/foreman_openscap/asset_extensions.rb,
app/models/concerns/foreman_openscap/arf_report_extensions.rb,
app/models/concerns/foreman_openscap/scap_content_extensions.rb,
app/helpers/concerns/foreman_openscap/hosts_helper_extensions.rb
Overview
Copyright (c) 2014 Red Hat Inc.
This software is licensed to you under the GNU General Public License, version 3 (GPLv3). There is NO WARRANTY for this software, express or implied, including the implied warranties of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. You should have received a copy of GPLv3 along with this software; if not, see http://www.gnu.org/licenses/gpl.txt
Defined Under Namespace
Modules: ArfReportExtensions, AssetExtensions, Helper, HostExtensions, HostsHelperExtensions, PolicyExtensions, ScapContentExtensions Classes: Engine
Constant Summary collapse
- VERSION =
"0.3.2"