Module: ForemanOpenscap::Helper

Defined in:
lib/foreman_openscap/helper.rb

Overview

Copyright (c) 2014 Red Hat Inc.

This software is licensed to you under the GNU General Public License, version 3 (GPLv3). There is NO WARRANTY for this software, express or implied, including the implied warranties of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. You should have received a copy of GPLv3 along with this software; if not, see http://www.gnu.org/licenses/gpl.txt

Class Method Summary collapse

Class Method Details

.get_asset(cname) ⇒ Object



12
13
14
# File 'lib/foreman_openscap/helper.rb', line 12

def self.get_asset(cname)
  Host.find_by_name!(cname).get_asset
end