Module: ArfReportsHelper
- Defined in:
- app/helpers/arf_reports_helper.rb
Overview
Copyright (c) 2014 Red Hat Inc.
This software is licensed to you under the GNU General Public License, version 3 (GPLv3). There is NO WARRANTY for this software, express or implied, including the implied warranties of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. You should have received a copy of GPLv3 along with this software; if not, see http://www.gnu.org/licenses/gpl.txt
Instance Method Summary collapse
Instance Method Details
#report_arf_column(event, style = "") ⇒ Object
12 13 14 15 |
# File 'app/helpers/arf_reports_helper.rb', line 12 def report_arf_column(event, style = "") style = "label-default" if event == 0 content_tag(:span, event, :class=>'label ' + style) end |