Class: ScaptimonyPolicyDashboardController
- Inherits:
-
ApplicationController
- Object
- ApplicationController
- ScaptimonyPolicyDashboardController
- Defined in:
- app/controllers/scaptimony_policy_dashboard_controller.rb
Overview
Copyright (c) 2014 Red Hat Inc.
This software is licensed to you under the GNU General Public License, version 3 (GPLv3). There is NO WARRANTY for this software, express or implied, including the implied warranties of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. You should have received a copy of GPLv3 along with this software; if not, see http://www.gnu.org/licenses/gpl.txt
Instance Method Summary collapse
Instance Method Details
#index ⇒ Object
14 |
# File 'app/controllers/scaptimony_policy_dashboard_controller.rb', line 14 def index; end |
#prefetch_data ⇒ Object
16 17 18 19 20 |
# File 'app/controllers/scaptimony_policy_dashboard_controller.rb', line 16 def prefetch_data @policy = ::Scaptimony::Policy.find(params[:id]) dashboard = Scaptimony::PolicyDashboard::Data.new(@policy, params[:search]) @report = dashboard.report end |